--[[
Copyright 2012-2013 João Cardoso
PetTracker is distributed under the terms of the GNU General Public License (Version 3).
As a special exception, the copyright holders of this addon do not give permission to
redistribute and/or modify it.

This addon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the addon. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.

This file is part of PetTracker.
--]]

local _, Addon = ...
local Tracker = Addon:NewClass('Frame', 'ZoneTracker', nil, Addon.List)

local DarkYellow = PASSIVE_SPELL_FONT_COLOR
local Drop = WatchFrameHeaderDropDown
local Journal = Addon.Journal


--[[ Startup ]]--

function Tracker:OnCreate()
	self.__super.OnCreate(self)

	self.Title = Addon.Line(self)
	self.Title.text:SetTextColor(DarkYellow.r, DarkYellow.g, DarkYellow.b)
	self.Title.text:SetText('Battle Pets')

	self.Bar = Addon.ProgressBar(self)
	self.Bar:SetPoint('TOPLEFT', self.Title, 'BOTTOMLEFT', 0, -2)
	self.Anchor = self.Bar
end

function Tracker:AnchorWatchFrame()
	self:RegisterEvent('PET_JOURNAL_LIST_UPDATE')
	self:SetScript('OnEvent', function()
		WatchFrame_Update()
	end)
	
	WatchFrame_AddObjectiveHandler(function(parent, anchor, _, width)
		self:Reset()
		
		if PetTracker_NoTracking then
			self:Hide()
		else
			self:SetWidth(width)
			self:SetParent(parent)
			self:DisplayAt(anchor)
			self:Show()
		end
		
		return self:Last(), 0, self:Count(), 0
	end)
	
	hooksecurefunc(Drop, 'initialize', function()
		UIDropDownMenu_AddButton {
			text = 'Battle Pets',
			checked = not PetTracker_NoTracking,
			isNotRadio = true,
			func = function()
				PetTracker_NoTracking = not PetTracker_NoTracking
				WatchFrame_Update()
			end
		}

		UIDropDownMenu_AddButton {
			text = 'Captured Pets',
			checked = PetTracker_CapturedPets,
			isNotRadio = true,
			func = function()
				PetTracker_CapturedPets = not PetTracker_CapturedPets
				WatchFrame_Update()
			end
		}
	end)
end


--[[ Display ]]--

function Tracker:DisplayAt(anchor)
	local progress = Journal:GetCurrentProgress()
	local point = anchor and 'BOTTOMLEFT' or 'TOPLEFT'
	local at = anchor or self:GetParent()
	
	self.Title:SetPoint('TOPLEFT', at, point, 2, -4)
	self.Bar:SetWidth(self:GetWidth() - 5)
	self.Bar:SetProgress(progress)

	for quality = 0, PetTracker_CapturedPets and Addon.MaxQuality or 0 do
		for i, specie in ipairs(progress[quality]) do
			self:AddSpecie(quality, specie)
		end
	end
end

function Tracker:AddSpecie(quality, specie)
	local sourceIcon = Journal:GetSourceIcon(specie)
	if sourceIcon then
		local name, icon = Journal:GetInfo(specie)
		local r,g,b = self:GetColor(quality)
		
		local line = self:NewLine()
		line.subIcon:SetTexture(sourceIcon)
		line.icon:SetTexture(icon)
		line.text:SetTextColor(r,g,b)
		line.text:SetText(name)
	end
end

function Tracker:GetColor(quality)
	if PetTracker_CapturedPets then
		return Addon:GetQualityColor(quality)
	end
	return .8,.8,.8
end

Tracker():AnchorWatchFrame()